==> lxqt-notificationd_0.16.0.orig.tar.xz: lxqt-notificationd-0.16.0/config/translations/lxqt-config-notificationd_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>Размеры</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>Расстояние:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Некоторые уведомления сами устанавливают свою длительность на экране.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>Длительность по умолчанию:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Непрочитанные уведомления</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Сколько сохранять:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>Имя приложения находится вверху уведомления.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>Игнорировать приложения:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>app1,app2,app3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Расположение на экране</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="61"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="70"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Демон уведомлений не запущен.
Будет использован резервный вариант.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="73"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Запущен сторонний демон уведомлений (%1).
Эти настройки не будут иметь никакого эффекта для него!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="131"/>
        <source>Notification demo </source>
        <translation>Тестовое уведомление </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="132"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Это тестовое уведомление.
 Теперь все уведомления LQXt будут появляться здесь.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Системные уведомления</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>Расширенные настройки</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_0.17.0.orig.tar.xz: lxqt-notificationd-0.17.0/config/translations/lxqt-config-notificationd_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>Размеры</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>Расстояние:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Некоторые уведомления сами устанавливают свою длительность на экране.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>Длительность по умолчанию:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation>Экран</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Если не отмечено, но уведомления будут показываться на основном экране</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Показывать уведомления на экране, на котором находится мышь</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Непрочитанные уведомления</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Сколько сохранять:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>Имя приложения находится вверху уведомления.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>Игнорировать приложения:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>app1,app2,app3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Расположение на экране</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="61"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Предупреждение:&lt;/b&gt; демон уведомлений не отвечает в течении значительно времени.
Продолжаем попытки соединения…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="70"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Демон уведомлений не запущен.
Будет использован резервный вариант.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="73"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Запущен сторонний демон уведомлений (%1).
Эти настройки не будут иметь никакого эффекта для него!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="131"/>
        <source>Notification demo </source>
        <translation>Тестовое уведомление </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="132"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Это тестовое уведомление.
 Теперь все уведомления LQXt будут появляться здесь.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Системные уведомления</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>Расширенные настройки</translation>
    </message>
</context>
</TS>
